
<h4 align="center">

[![PyPI Downloads](https://img.shields.io/pypi/dm/NepTrainKit?logo=pypi&logoColor=white&color=blue&label=PyPI)](https://pypi.org/project/NepTrainKit)
[![Requires Python 3.10+](https://img.shields.io/badge/Python-3.10+-blue.svg?logo=python&logoColor=white)](https://python.org/downloads)
 
</h4>

[中文](README_zh.md)


#  About NepTrainKit
NepTrainKit is a toolkit focused on the operation and visualization of neuroevolution potential(NEP) training datasets. It is mainly used to simplify and optimize the NEP model training process, providing an intuitive graphical interface and analysis tools to help users adjust hyperparameters and evaluate model performance more efficiently.
# Community Support

- Join the community chat (https://qm.qq.com/q/wPDQYHMhyg)
- Raise issues and engage in discussions via GitHub issues


# Installation
**It is strongly recommended to use pip to install, which will compile the OpenMP version and significantly speed up the acquisition of descriptors.**
- Install directly using the pip install command: `pip install NepTrainKit`. After installation, you can call the program using `NepTrainKit` or `nepkit`.
- Go to the **release** page of this project to download the executable **NepTrainKit.win32.zip**. Currently, this program only supports Windows systems.